@@ -3,7 +3,7 @@ import requests
 def sigg(data):
     da={"data":data}
     try:
-        r=requests.post(f'https://bakusig.herokuapp.com/sig-gen',data=da)
+        r=requests.post(f'https://sigg123.herokuapp.com/sig-gen',data=da)
         return r.json()["sig"]
     except:
         sigg(data)
